@@ -3,4 +3,4 @@ from __future__ import absolute_import
 # flake8: noqa
 
 # import apis into api package
-from hubspot.cms.blogs.tags.api.tag_api import TagApi
+from hubspot.cms.blogs.tags.api.blog_tags_api import BlogTagsApi
